@@ -60,16 +60,6 @@ class Sprite(object):
           :attr:`image_yscale` attribute of a :class:`sge.StellarClass`
           object instead.
 
-    .. attribute:: origin_x
-
-       The horizontal location of the origin relative to the left edge
-       of the images.
-
-    .. attribute:: origin_y
-
-       The vertical location of the origin relative to the top edge of
-       the images.
-
     .. attribute:: transparent
 
        Whether or not the image should be partially transparent.  If an
@@ -77,6 +67,16 @@ class Sprite(object):
        with the transparent color being the color of the top-rightmost
        pixel.
 
+    .. attribute:: origin_x
+
+       The suggested horizontal location of the origin relative to the
+       left edge of the images.
+
+    .. attribute:: origin_y
+
+       The suggested vertical location of the origin relative to the top
+       edge of the images.
+
     .. attribute:: fps
 
        The suggested rate in frames per second to animate the image at.
@@ -123,7 +123,7 @@ class Sprite(object):
     """
 
     def __init__(self, name=None, ID=None, width=None, height=None,
-                 origin_x=0, origin_y=0, transparent=True, fps=60,
+                 transparent=True, origin_x=0, origin_y=0, fps=60,
                  bbox_x=None, bbox_y=None, bbox_width=None,
                  bbox_height=None):
         """Constructor method.
